==> ejc-supbid-api-3.0.1-20211119.102144-2-sources.jar: com/ejianc/business/supbid/material/vo/SchemeVO.java <==
package com.ejianc.business.supbid.material.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;

import com.ejianc.business.supbid.material.vo.SchemeDetailVO;

/**
 * 方案实体
 * 
 * @author generator
 * 
 */
@ApiModel("方案实体")
public class SchemeVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    @ApiModelProperty("主表主键")
    private java.lang.Long noticeId;
    @ApiModelProperty("招标信息主键")
    private java.lang.String sourceId;
    @ApiModelProperty("方案名称")
    private java.lang.String planName;
    @ApiModelProperty("报价总额")
    private java.math.BigDecimal money;
    @ApiModelProperty("报价总额(含税)")
    private java.math.BigDecimal moneyTax;
    
    @ApiModelProperty("报价明细实体")
    private List<SchemeDetailVO> schemeDetailVos = new ArrayList<>();

    /**
     * 主表主键
     */
    public java.lang.Long getNoticeId() {
        return noticeId;
    }

    /**
     * 主表主键
     */
    public void setNoticeId(java.lang.Long noticeId) {
        this.noticeId = noticeId;
    }
    /**
     * 招标信息主键
     */
    public java.lang.String getSourceId() {
        return sourceId;
    }

    /**
     * 招标信息主键
     */
    public void setSourceId(java.lang.String sourceId) {
        this.sourceId = sourceId;
    }
    /**
     * 方案名称
     */
    public java.lang.String getPlanName() {
        return planName;
    }

    /**
     * 方案名称
     */
    public void setPlanName(java.lang.String planName) {
        this.planName = planName;
    }
    /**
     * 报价总额
     */
    public java.math.BigDecimal getMoney() {
        return money;
    }

    /**
     * 报价总额
     */
    public void setMoney(java.math.BigDecimal money) {
        this.money = money;
    }
    /**
     * 报价总额(含税)
     */
    public java.math.BigDecimal getMoneyTax() {
        return moneyTax;
    }

    /**
     * 报价总额(含税)
     */
    public void setMoneyTax(java.math.BigDecimal moneyTax) {
        this.moneyTax = moneyTax;
    }
    
     /**
      * 报价明细实体
      */
     public List<SchemeDetailVO> getSchemeDetailVos() {
        return schemeDetailVos;
     }

     /**
      * 报价明细实体
      */
     public void setSchemeDetailVos(List<SchemeDetailVO> schemeDetailVos) {
        this.schemeDetailVos = schemeDetailVos;
     }
}

==> ejc-supbid-api-3.0.1-20211123.065828-3-sources.jar: com/ejianc/business/supbid/material/vo/SchemeVO.java <==
package com.ejianc.business.supbid.material.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;

import com.ejianc.business.supbid.material.vo.SchemeDetailVO;

/**
 * 方案实体
 * 
 * @author generator
 * 
 */
@ApiModel("方案实体")
public class SchemeVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    @ApiModelProperty("主表主键")
    private java.lang.Long noticeId;
    @ApiModelProperty("招标信息主键")
    private java.lang.String sourceId;
    @ApiModelProperty("方案名称")
    private java.lang.String schemeName;
    @ApiModelProperty("报价总额")
    private java.math.BigDecimal money;
    @ApiModelProperty("报价总额(含税)")
    private java.math.BigDecimal moneyTax;
    
    @ApiModelProperty("报价明细实体")
    private List<SchemeDetailVO> schemeDetailVos = new ArrayList<>();

    /**
     * 主表主键
     */
    public java.lang.Long getNoticeId() {
        return noticeId;
    }

    /**
     * 主表主键
     */
    public void setNoticeId(java.lang.Long noticeId) {
        this.noticeId = noticeId;
    }
    /**
     * 招标信息主键
     */
    public java.lang.String getSourceId() {
        return sourceId;
    }

    /**
     * 招标信息主键
     */
    public void setSourceId(java.lang.String sourceId) {
        this.sourceId = sourceId;
    }

    public String getSchemeName() {
        return schemeName;
    }

    public void setSchemeName(String schemeName) {
        this.schemeName = schemeName;
    }

    /**
     * 报价总额
     */
    public java.math.BigDecimal getMoney() {
        return money;
    }

    /**
     * 报价总额
     */
    public void setMoney(java.math.BigDecimal money) {
        this.money = money;
    }
    /**
     * 报价总额(含税)
     */
    public java.math.BigDecimal getMoneyTax() {
        return moneyTax;
    }

    /**
     * 报价总额(含税)
     */
    public void setMoneyTax(java.math.BigDecimal moneyTax) {
        this.moneyTax = moneyTax;
    }
    
     /**
      * 报价明细实体
      */
     public List<SchemeDetailVO> getSchemeDetailVos() {
        return schemeDetailVos;
     }

     /**
      * 报价明细实体
      */
     public void setSchemeDetailVos(List<SchemeDetailVO> schemeDetailVos) {
        this.schemeDetailVos = schemeDetailVos;
     }
}
